@@ -4,9 +4,9 @@
 #' \link{lsirm2pl_mar} factorizes item response matrix into column-wise item effect, row-wise respondent effect in a latent space, while considering the missing element under the assumption of missing at random. Unlike 1PL model, 2PL model assumes the item effect can vary according to respondent, allowing additional parameter multiplied with respondent effect.  The resulting latent space provides an interaction map that represents interactions between respondents and items.
 #'
 #' @inheritParams lsirm2pl
-#' @param jump_gamma Numeric; the jumping rule for the gamma proposal density. Default is 0.025.
+#' @param jump_gamma Numeric; the jumping rule for the gamma proposal density. Default is 0.2.
 #' @param pr_mean_gamma Numeric; mean of log normal prior for gamma. Default is 0.5.
-#' @param pr_sd_gamma Numeric; standard deviation of log normal prior for gamma. Default is 1.0.
+#' @param pr_sd_gamma Numeric; standard deviation of log normal prior for gamma. Default is 1.
 #' @param missing.val Numeric; A number to replace missing values. Default is 99.
 #' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. Default is FALSE.
 #'
@@ -63,7 +63,7 @@
 #' }
 #' @export
 lsirm2pl_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin = 5, nprint = 500,
-                        jump_beta = 0.4, jump_theta = 1, jump_alpha = 1.0, jump_gamma = 0.025, jump_z = 0.5, jump_w = 0.5,
+                        jump_beta = 0.4, jump_theta = 1, jump_alpha = 1, jump_gamma = 0.2, jump_z = 0.5, jump_w = 0.5,
                         pr_mean_beta = 0, pr_sd_beta = 1, pr_mean_theta = 0, pr_sd_theta = 1, pr_mean_gamma = 0.5, pr_sd_gamma = 1,
                         pr_mean_alpha = 0.5, pr_sd_alpha = 1, pr_a_theta = 0.001, pr_b_theta = 0.001,
                         missing.val = 99, verbose=FALSE, fix_theta_sd=FALSE, fix_alpha_1=TRUE){
@@ -75,6 +75,9 @@ lsirm2pl_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin = 5,
   }else{
     cname = paste("item", 1:ncol(data), sep=" ")
   }
+  
+  # Convert NA to missing.val
+  data[is.na(data)] <- missing.val
 
   # cat("\n\nFitting with MCMC algorithm\n")
 
@@ -135,8 +138,13 @@ cat("\n")
 
   # Calculate BIC
   # cat("\n\nCalculate BIC\n")
-  missing_est = ifelse(imp.estimate > 0.5, 1, 0)
-  data[data == missing.val] = missing_est
+  if (!is.null(output$impute) && ncol(output$impute) > 0) {
+    missing_est = ifelse(imp.estimate > 0.5, 1, 0)
+    missing_indices = which(data == missing.val)
+    if (length(missing_indices) == length(missing_est)) {
+      data[missing_indices] = missing_est
+    }
+  }
   log_like = log_likelihood_2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), gamma.estimate, z.est, w.est, missing.val)
   p = 2 * nitem + nsample + 1 + 1 + ndim * nitem + ndim * nsample
   bic = -2 * log_like[[1]] + p * log(nsample * nitem)
@@ -171,6 +179,14 @@ cat("\n")
                  accept_z       = output$accept_z,
                  accept_gamma   = output$accept_gamma,
                  accept_alpha   = output$accept_alpha)
+  result$call <- match.call()
+  result$method <- "lsirm2pl"
+  result$missing <- "mar"
+  result$varselect <- FALSE
+  result$dtype <- "binary"
+  result$chains <- 1
+  result$fixed_gamma <- FALSE
+
   class(result) = "lsirm"
 
   return(result)
