@@ -59,7 +59,7 @@
 #'
 #' @export
 lsirm2pl_normal_fixed_gamma_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin = 5, nprint = 500,
-                                           jump_beta = 0.4, jump_theta = 1.0, jump_alpha = 1.0, jump_z = 0.5, jump_w = 0.5,
+                                           jump_beta = 0.4, jump_theta = 1.0, jump_alpha = 1, jump_z = 0.5, jump_w = 0.5,
                                            pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0, pr_sd_theta = 1.0,
                                            pr_mean_alpha = 0.5, pr_sd_alpha = 1,
                                            pr_a_theta = 0.001, pr_b_theta = 0.001,pr_a_eps = 0.001, pr_b_eps = 0.001, missing.val = 99, verbose=FALSE, fix_theta_sd=FALSE, fix_alpha_1=TRUE){
@@ -133,7 +133,6 @@ cat("\n")
   # Calculate BIC
   # cat("\n\nCalculate BIC\n")
   missing_est = ifelse(imp.estimate > 0.5, 1, 0)
-  data[data == missing.val] = missing_est
   log_like = log_likelihood_normal2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), 1, z.est, w.est, sigma.estimate, missing.val)
   p = 2 * nitem + nsample + 1 + ndim * nitem + ndim * nsample + 1
   bic = -2 * log_like[[1]] + p * log(nitem * nsample)
