@@ -4,9 +4,9 @@
 #' \link{lsirm2pl_normal_mar} factorizes item response matrix into column-wise item effect, row-wise respondent effect and further embeds interaction effect in a latent space, while considering the missing element under the assumption of missing at random. Unlike 1PL model, 2PL model assumes the item effect can vary according to respondent, allowing additional parameter multiplied with respondent effect. The resulting latent space provides an interaction map that represents interactions between respondents and items.
 #'
 #' @inheritParams lsirm2pl
-#' @param jump_gamma Numeric; the jumping rule for the gamma proposal density. Default is 0.025
+#' @param jump_gamma Numeric; the jumping rule for the gamma proposal density. Default is 0.2
 #' @param pr_mean_gamma Numeric; mean of log normal prior for gamma. Default is 0.5.
-#' @param pr_sd_gamma Numeric; standard deviation of log normal prior for gamma. Default is 1.0.
+#' @param pr_sd_gamma Numeric; standard deviation of log normal prior for gamma. Default is 1.
 #' @param pr_a_eps Numeric; the shape parameter of inverse gamma prior for variance of data likelihood. Default is 0.001.
 #' @param pr_b_eps Numeric; the scale parameter of inverse gamma prior for variance of data likelihood. Default is 0.001.
 #' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. Default is FALSE.
@@ -24,7 +24,7 @@
 #' \item{gamma_estimate}{posterior estimates of gamma parameter.}
 #' \item{z_estimate}{Posterior estimates of the z parameter.}
 #' \item{w_estimate}{Posterior estimates of the w parameter.}
-#'  \item{imp_estimate}{Probability of imputating a missing value with 1.}
+#'  \item{imp_estimate}{Posterior mean imputation for each missing cell.}
 #' \item{beta}{Posterior samples of the beta parameter.}
 #' \item{theta}{Posterior samples of the theta parameter.}
 #' \item{gamma}{Posterior samples of the gamma parameter.}
@@ -42,10 +42,10 @@
 #' \item{sigma_estimate}{Posterior estimates of the standard deviation.}
 #' \item{sigma}{Posterior samples of the standard deviation.}
 #' \item{alpha_estimate}{Posterior estimates of the alpha parameter.}
-#'  \item{alpha}{Posterior estimates of the alpha parameter.}
+#'  \item{alpha}{Posterior samples of the alpha parameter.}
 #'  \item{accept_alpha}{Acceptance ratio for the alpha parameter.}
 #'
-#' @details \code{lsirm2pl_normal_mar} models the continuous value of response by respondent \eqn{j} to item \eqn{i} with item effect \eqn{\beta_i}, respondent effect \eqn{\theta_j} and the distance between latent position \eqn{w_i} of item \eqn{i} and latent position \eqn{z_j} of respondent \eqn{j} in the shared metric space, with \eqn{\gamma} represents the weight of the distance term. For 2pl model, the the item effect is assumed to have additional discrimination parameter \eqn{\alpha_i} multiplied by \eqn{\theta_j}: \deqn{Y_{j,i} = \theta_j+\beta_i-\gamma||z_j-w_i|| + e_{j,i}} where the error \eqn{e_{j,i} \sim N(0,\sigma^2)} Under the assumption of missing at random, the model takes the missing element into consideration in the sampling procedure. For the details of missing at random assumption and data augmentation, see References.
+#' @details \code{lsirm2pl_normal_mar} models the continuous value of response by respondent \eqn{j} to item \eqn{i} with item effect \eqn{\beta_i}, respondent effect \eqn{\theta_j} and the distance between latent position \eqn{w_i} of item \eqn{i} and latent position \eqn{z_j} of respondent \eqn{j} in the shared metric space, with \eqn{\gamma} represents the weight of the distance term. For 2pl model, the the item effect is assumed to have additional discrimination parameter \eqn{\alpha_i} multiplied by \eqn{\theta_j}: \deqn{Y_{j,i} = \alpha_i\theta_j+\beta_i-\gamma||z_j-w_i|| + e_{j,i}} where the error \eqn{e_{j,i} \sim N(0,\sigma^2)} Under the assumption of missing at random, the model takes the missing element into consideration in the sampling procedure. For the details of missing at random assumption and data augmentation, see References.
 #'
 #' @references  Little, R. J., & Rubin, D. B. (2019). Statistical analysis with missing data (Vol. 793). John Wiley & Sons.
 #' @examples
@@ -65,7 +65,7 @@
 #'                       missing_data = "mar"))
 #' @export
 lsirm2pl_normal_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin = 5, nprint = 500,
-                               jump_beta = 0.4, jump_theta = 1.0, jump_alpha = 1.0, jump_gamma = 1.0, jump_z = 0.5, jump_w = 0.5,
+                               jump_beta = 0.4, jump_theta = 1.0, jump_alpha = 1, jump_gamma = 1.0, jump_z = 0.5, jump_w = 0.5,
                                pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0, pr_sd_theta = 1.0,
                                pr_mean_gamma = 0.5, pr_sd_gamma =1.0,
                                pr_mean_alpha = 0.5, pr_sd_alpha = 1,
@@ -79,9 +79,9 @@ lsirm2pl_normal_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthi
   }else{
     cname = paste("item", 1:ncol(data), sep=" ")
   }
-
-  # cat("\n\nFitting with MCMC algorithm\n")
-
+  
+  # Convert NA to missing.val
+  data[is.na(data)] <- missing.val
 
   output <- lsirm2pl_normal_mar_cpp(data=as.matrix(data),
                                     ndim=ndim, niter=niter, nburn=nburn, nthin=nthin, nprint=nprint,
@@ -103,9 +103,6 @@ lsirm2pl_normal_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthi
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
 
-  # cat("\n\nProcrustes Matching Analysis\n")
-cat("\n")
-
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     w.iter = output$w[iter,,]
@@ -133,36 +130,35 @@ cat("\n")
   sigma_theta.estimate = mean(output$sigma_theta)
   sigma.estimate = mean(output$sigma)
   gamma.estimate = mean(output$gamma)
-  imp.estimate = apply(output$impute, 2, mean)
-
+  imp.estimate = if(!is.null(output$impute)) apply(output$impute, 2, mean) else numeric(0)
 
   beta.summary = data.frame(cbind(apply(output$beta, 2, mean), t(apply(output$beta, 2, function(x) quantile(x, probs = c(0.025, 0.975))))))
   colnames(beta.summary) <- c("Estimate", "2.5%", "97.5%")
   rownames(beta.summary) <- cname
 
   # Calculate BIC
-  # cat("\n\nCalculate BIC\n")
-  missing_est = ifelse(imp.estimate > 0.5, 1, 0)
-  data[data == missing.val] = missing_est
+  if (length(imp.estimate) > 0) {
+    data[data == missing.val] = imp.estimate
+  }
   log_like = log_likelihood_normal2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), gamma.estimate, z.est, w.est, sigma.estimate, missing.val)
-  p = 2 * nitem + nsample + 1 + 1 + ndim * nitem + ndim * nsample + 1
+  p = 2 * nitem + nsample + 1 + 1 + ndim * nitem + ndim * nsample + 1 + 1 # added sigma
   bic = -2 * log_like[[1]] + p * log(nitem * nsample)
 
   result <- list(data = data,
-              missing.val = missing.val,
-              bic = bic,
+                 missing.val = missing.val,
+                 bic = bic,
                  mcmc_inf = mcmc.inf,
                  map_inf = map.inf,
                  beta_estimate  = beta.estimate,
                  beta_summary = beta.summary,
                  theta_estimate = theta.estimate,
-                 sigma_theta_estimate    = sigma_theta.estimate,
+                 sigma_theta_estimate = sigma_theta.estimate,
                  sigma_estimate = sigma.estimate,
                  gamma_estimate = gamma.estimate,
                  alpha_estimate = alpha.estimate,
                  z_estimate     = z.est,
                  w_estimate     = w.est,
-                 imp_estimate   = imp.estimate,
+                 imp_estimate  = imp.estimate,
                  beta           = output$beta,
                  theta          = output$theta,
                  theta_sd       = output$sigma_theta,
@@ -180,6 +176,15 @@ cat("\n")
                  accept_z       = output$accept_z,
                  accept_gamma   = output$accept_gamma,
                  accept_alpha   = output$accept_alpha)
+  
+  result$call <- match.call()
+  result$method <- "lsirm2pl"
+  result$missing <- "mar"
+  result$varselect <- FALSE
+  result$dtype <- "continuous"
+  result$chains <- 1
+  result$fixed_gamma <- FALSE
+  
   class(result) = "lsirm"
 
   return(result)
